﻿-- Author      : Deldinor of Elune
-- Create Date : 2/20/2011 3:01:53 PM

function DailyGrind:ShowOptions()
	InterfaceOptionsFrame_OpenToCategory(addonName)
end

DailyGrind.Options = {
	type = "group",
	name = addonFullName,
	get = function(info) return DailyGrindSettings[ info[#info] ] end,
	set = function(info, value) DailyGrindSettings[ info[#info] ] = value end,
	args = {
		General = {
			order = 1,
			type = "group",
			name = "General Settings",
			desc = "General Settings",
			args = {
				Enabled = {
					type = "toggle",
					name = "Enabled",
					desc = "Enables or disables "..addonTitle.."'s automation functions, though your completed quests will still be recorded.",
					order = 1,
					set = function(info, value)
						DailyGrind:SetEnabled(value);
					end,
				},
				intro = {
					order = 2,
					type = "description",
					name = "\n"..addonTitle.." auto-accepts and auto-completes daily and repeatable quests as you encounter them.\n\nDaily quests that you complete are added to your quest history. Whenever you see that daily again, you will automatically accept and complete it. This approach is taken so that players may read through quests that they have not yet encountered.\n"
				},
				Blacklist = {
					type = "input",
					multiline = true,
					name = "Blacklist",
					desc = "Add any quests that you don't want "..addonTitle.." to auto-accept or auto-complete, |c"..commandColor.."one quest per line|r. Proper capitalization is not required, but all other characters in the quest name must be accurate.",
					order = 3,
					get = function(info)
						return DailyGrind:Blacklist_ToString();
					end,
					set = function(info, value)
						local questList = { strsplit("\n", value:trim()) };
						DailyGrind:Blacklist_Populate(questList);
					end,
				},
				Rewards = {
					type = "input",
					multiline = true,
					name = "Reward List",
					desc = "Add any quest rewards that you want "..addonTitle.." to automatically select, |c"..commandColor.."one item per line|r. Proper capitalization is not required, but all other characters in the item name must be accurate.",
					order = 4,
					get = function(info)
						return DailyGrind:RewardList_ToString();
					end,
					set = function(info, value)
						local itemList = { strsplit("\n", value:trim()) };
						DailyGrind:RewardList_Populate(itemList);
					end,
				},
				questHistoryGroup = {
					type = "group",
					name = "Quest History",
					guiInline = true,
					order = 10,
					args = {
						importIntro = {
							order = 1,
							type = "description",
							name = "A list of currently-known dailies is included. If you wish to speed things up (i.e., not have to manually click through quests at least once), you may import this list into your database using the |c"..commandColor.."Fill Quest History|r button below. This list is current as of patch 4.3 (working on something new for 5.0).\n\nYou may also start over by clicking the |c"..commandColor.."Clear Quest History|r button.\n"
						},
						import = {
							type = "execute",
							order = 2,
							name = "Fill Quest History",
							desc = "Import all currently-known daily quests into your history. This applies to all characters on your account.",
							func = function()
								DailyGrind:Import();
							end,
						},
						clear = {
							type = "execute",
							order = 3,
							name = "Clear Quest History",
							desc = "Reset your quest history. This applies to all characters on your account.",
							func = function()
								DailyGrind:Reset();
							end,
						},
					},
				},
			},
		},
	},
}
